==> bfilter-0.10.3.tar.gz: bfilter-0.10.3/main/ProxyDescriptor.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef PROXYDESCRIPTOR_H_
#define PROXYDESCRIPTOR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "InetAddr.h"
#include <string>

class ProxyDescriptor
{
public:
	explicit ProxyDescriptor(InetAddr const& addr);
	
	explicit ProxyDescriptor(std::string const& config_problem);
	
	ProxyDescriptor(ProxyDescriptor const& other);
	
	~ProxyDescriptor();
	
	ProxyDescriptor& operator=(ProxyDescriptor const& other);
	
	void swap(ProxyDescriptor& other);
	
	InetAddr const& getProxyAddr() const { return m_addr; }
	
	bool hasProblem() const { return !m_configProblem.empty(); }
	
	std::string const& getProblem() const { return m_configProblem; }
private:
	InetAddr m_addr;
	std::string m_configProblem;
};

inline void swap(ProxyDescriptor& o1, ProxyDescriptor& o2)
{
	o1.swap(o2);
}

#endif

==> bfilter_1.0.2.orig.tar.gz: bfilter-1.0.2/main/ProxyDescriptor.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef PROXYDESCRIPTOR_H_
#define PROXYDESCRIPTOR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "SymbolicInetAddr.h"
#include <string>

class ProxyDescriptor
{
public:
	explicit ProxyDescriptor(SymbolicInetAddr const& addr);
	
	explicit ProxyDescriptor(std::string const& config_problem);
	
	ProxyDescriptor(ProxyDescriptor const& other);
	
	~ProxyDescriptor();
	
	ProxyDescriptor& operator=(ProxyDescriptor const& other);
	
	void swap(ProxyDescriptor& other);
	
	SymbolicInetAddr const& getProxyAddr() const { return m_addr; }
	
	bool hasProblem() const { return !m_configProblem.empty(); }
	
	std::string const& getProblem() const { return m_configProblem; }
private:
	SymbolicInetAddr m_addr;
	std::string m_configProblem;
};

inline void swap(ProxyDescriptor& o1, ProxyDescriptor& o2)
{
	o1.swap(o2);
}

#endif
